# writeprints-static

Extract lexical and syntactic features for authorship attribution research.

The writeprints-static package aims to reproduce "Writeprints-Static" featureset described in Brennan et al. (2012).
Check [Docs](https://literary-materials.github.io/writeprints-static/) for details.


## License

This package is licensed under the ISC License.

## Versions

- May 4, 2022, launch v.0.0.1. 

## References

- Brennan, M., Afroz, S., & Greenstadt, R. (2012). Adversarial stylometry: Circumventing authorship recognition to
preserve privacy and anonymity. *ACM Transactions on Information and System Security (TISSEC)*, 15(3), 1-22.

